aboutsummaryrefslogtreecommitdiffstats
path: root/home/text.asm
diff options
context:
space:
mode:
authorSylvie <35663410+Rangi42@users.noreply.github.com>2024-09-18 21:01:18 -0400
committerGitHub <noreply@github.com>2024-09-18 21:01:18 -0400
commit613d34678b7e9da1a467ec48fff23bfa75209871 (patch)
treec21669899a90df25aaac9b4b4d213ac525d6f277 /home/text.asm
parentUse correct label in get_trainer_name.asm (#461) (diff)
downloadpokeyellow-613d34678b7e9da1a467ec48fff23bfa75209871.tar.gz
pokeyellow-613d34678b7e9da1a467ec48fff23bfa75209871.tar.xz
pokeyellow-613d34678b7e9da1a467ec48fff23bfa75209871.zip
Split `hSpriteIndexOrTextID` into `hSpriteIndex` and `hTextID` (#462)
Also identify `wPPUpCountAndMaxPP`
Diffstat (limited to 'home/text.asm')
-rw-r--r--home/text.asm4
1 files changed, 2 insertions, 2 deletions
diff --git a/home/text.asm b/home/text.asm
index e815fbf7..dc78b982 100644
--- a/home/text.asm
+++ b/home/text.asm
@@ -117,13 +117,13 @@ NullChar:: ; unused
pop hl
; A "<NULL>" character in a printed string
; displays an error message with the current value
; of hSpriteIndexOrTextID in decimal format.
; This is a debugging leftover.
ld de, TextIDErrorText
dec de
ret
-TextIDErrorText:: ; "[hSpriteIndexOrTextID] ERROR."
+TextIDErrorText:: ; "[hTextID] ERROR."
text_far _TextIDErrorText
text_end
@@ -117,13 +117,13 @@ NullChar:: ; unused
; A "<NULL>" character in a printed string
; displays an error message with the current value
- ; of hSpriteIndexOrTextID in decimal format.
+ ; of hTextID in decimal format.
; This is a debugging leftover.
ld de, TextIDErrorText